@@ -1,23 +1,21 @@
+pub mod api_config;
+pub use self::api_config::ApiConfig;
+pub mod api_event_config;
+pub use self::api_event_config::ApiEventConfig;
 pub mod avatar;
 pub use self::avatar::Avatar;
 pub mod avatar_unity_package_url_object;
 pub use self::avatar_unity_package_url_object::AvatarUnityPackageUrlObject;
-pub mod config;
-pub use self::config::Config;
-pub mod config_announcements;
-pub use self::config_announcements::ConfigAnnouncements;
-pub mod config_download_urls;
-pub use self::config_download_urls::ConfigDownloadUrls;
-pub mod config_dynamic_world_rows;
-pub use self::config_dynamic_world_rows::ConfigDynamicWorldRows;
-pub mod config_events;
-pub use self::config_events::ConfigEvents;
 pub mod current_user;
 pub use self::current_user::CurrentUser;
 pub mod deployment_group;
 pub use self::deployment_group::DeploymentGroup;
 pub mod developer_type;
 pub use self::developer_type::DeveloperType;
+pub mod download_url_list;
+pub use self::download_url_list::DownloadUrlList;
+pub mod dynamic_world_row;
+pub use self::dynamic_world_row::DynamicWorldRow;
 pub mod error;
 pub use self::error::Error;
 pub mod favorite;
@@ -90,6 +88,10 @@ pub mod invite_message;
 pub use self::invite_message::InviteMessage;
 pub mod invite_message_type;
 pub use self::invite_message_type::InviteMessageType;
+pub mod invite_request;
+pub use self::invite_request::InviteRequest;
+pub mod invite_response;
+pub use self::invite_response::InviteResponse;
 pub mod limited_unity_package;
 pub use self::limited_unity_package::LimitedUnityPackage;
 pub mod limited_user;
@@ -110,6 +112,8 @@ pub mod player_moderation;
 pub use self::player_moderation::PlayerModeration;
 pub mod player_moderation_type;
 pub use self::player_moderation_type::PlayerModerationType;
+pub mod public_announcement;
+pub use self::public_announcement::PublicAnnouncement;
 pub mod release_status;
 pub use self::release_status::ReleaseStatus;
 pub mod response;
@@ -120,6 +124,8 @@ pub mod unity_package;
 pub use self::unity_package::UnityPackage;
 pub mod user;
 pub use self::user::User;
+pub mod user_exists;
+pub use self::user_exists::UserExists;
 pub mod user_state;
 pub use self::user_state::UserState;
 pub mod user_status;
